@@ -10,7 +10,7 @@ import time
 
 
 class ConfuseCallback(tf.keras.callbacks.Callback):
-    def __init__(self, x_test, y_test, file_writer, class_names=None, figure_size=(12, 10)):
+    def __init__(self, x_test, y_test, file_writer, class_names=None, y_argmax=False, figure_size=(12, 10)):
         super(ConfuseCallback, self).__init__()
         self.x_test = x_test
         self.y_test = y_test
@@ -19,7 +19,7 @@ class ConfuseCallback(tf.keras.callbacks.Callback):
         self.class_names = class_names
 
         if self.class_names is None:
-            self.class_names = ["Class {:02d}".format(unique_label) for unique_label in np.unique(y_test)]
+            self.class_names = ["Class {:02d}".format(unique_label) for unique_label in np.unique(np.argmax(y_test, axis=1) if y_argmax else y_test)]
 
     def get_precision_recall_plot(self, con_mat):
         precisions = np.array([0] * len(self.class_names)).astype('float32')
@@ -141,7 +141,7 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
-                     confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, figure_size=(12, 10),
+                     confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, y_argmax=False, figure_size=(12, 10),
                      modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0,
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True):
     postfix = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
@@ -165,6 +165,7 @@ def get_tf_callbacks(root,
             callbacks_.append(ConfuseCallback(x_test, y_test,
                                               file_writer,
                                               class_names=label_info,
+                                              y_argmax=y_argmax,
                                               figure_size=figure_size)
                               )
 
